diff --git a/ghc-lib-parser.cabal b/ghc-lib-parser.cabal
--- a/ghc-lib-parser.cabal
+++ b/ghc-lib-parser.cabal
@@ -1,7 +1,7 @@
 cabal-version: 3.0
 build-type: Simple
 name: ghc-lib-parser
-version: 9.8.3.20241022
+version: 9.8.3.20241103
 license: BSD-3-Clause
 license-file: LICENSE
 category: Development
@@ -107,7 +107,7 @@
         process >= 1 && < 1.7
     if impl(ghc >= 9.10)
       build-depends: ghc-internal
-    build-tool-depends: alex:alex >= 3.1, happy:happy > 1.20 && < 2.0
+    build-tool-depends: alex:alex >= 3.1, happy:happy == 1.20.* || >= 2.0.2 && < 2.1
     other-extensions:
         BangPatterns
         CPP
diff --git a/ghc-lib/stage0/compiler/build/GHC/Settings/Config.hs b/ghc-lib/stage0/compiler/build/GHC/Settings/Config.hs
--- a/ghc-lib/stage0/compiler/build/GHC/Settings/Config.hs
+++ b/ghc-lib/stage0/compiler/build/GHC/Settings/Config.hs
@@ -22,7 +22,7 @@
 cProjectName          = "The Glorious Glasgow Haskell Compilation System"
 
 cBooterVersion        :: String
-cBooterVersion        = "9.8.2"
+cBooterVersion        = "9.8.3"
 
 cStage                :: String
 cStage                = show (1 :: Int)
diff --git a/ghc-lib/stage0/lib/settings b/ghc-lib/stage0/lib/settings
--- a/ghc-lib/stage0/lib/settings
+++ b/ghc-lib/stage0/lib/settings
@@ -1,10 +1,10 @@
-[("C compiler command", "/usr/bin/gcc")
+[("C compiler command", "/usr/local/opt/ccache/libexec/gcc")
 ,("C compiler flags", "--target=x86_64-apple-darwin  -Qunused-arguments")
-,("C++ compiler command", "/usr/bin/g++")
+,("C++ compiler command", "/usr/local/opt/ccache/libexec/g++")
 ,("C++ compiler flags", "--target=x86_64-apple-darwin ")
 ,("C compiler link flags", "--target=x86_64-apple-darwin   -Wl,-no_fixup_chains -Wl,-no_warn_duplicate_libraries")
 ,("C compiler supports -no-pie", "NO")
-,("Haskell CPP command", "/usr/bin/gcc")
+,("Haskell CPP command", "/usr/local/opt/ccache/libexec/gcc")
 ,("Haskell CPP flags", "-E -undef -traditional -Wno-invalid-pp-token -Wno-unicode -Wno-trigraphs")
 ,("ld command", "ld")
 ,("ld flags", "")

diff --git a/compiler/cbits/keepCAFsForGHCi.c b/compiler/cbits/keepCAFsForGHCi.c
--- a/compiler/cbits/keepCAFsForGHCi.c
+++ b/compiler/cbits/keepCAFsForGHCi.c
@@ -1,7 +1,7 @@
 #include <Rts.h>
 #include <ghcversion.h>
 
-// Note [keepCAFsForGHCi]
+// Note [ghc_lib_parser_keepCAFsForGHCi]
 // ~~~~~~~~~~~~~~~~~~~~~~
 // This file is only included in the dynamic library.
 // It contains an __attribute__((constructor)) function (run prior to main())
@@ -14,7 +14,7 @@
 // an archive and not otherwise referenced the linker would ignore the object.
 // To avoid this:
 // * When initializing a GHC session in initGhcMonad we assert keeping cafs has been
 //   enabled by calling keepCAFsForGHCi.
 // * This causes the GHC module from the ghc package to carry a reference to this object
 //   file.
 // * Which in turn ensures the linker doesn't discard this object file, causing
@@ -23,9 +23,9 @@
 
 
 
-bool keepCAFsForGHCi(void) __attribute__((constructor));
+bool ghc_lib_parser_keepCAFsForGHCi(void) __attribute__((constructor));
 
-bool keepCAFsForGHCi(void)
+bool ghc_lib_parser_keepCAFsForGHCi(void)
 {
     bool was_set = keepCAFs;
     setKeepCAFs();
@@ -14,7 +14,7 @@
 // To avoid this:
 // * When initializing a GHC session in initGhcMonad we assert keeping cafs has been
-//   enabled by calling keepCAFsForGHCi.
+//   enabled by calling ghc_lib_parser_keepCAFsForGHCi.
 // * This causes the GHC module from the ghc package to carry a reference to this object
 //   file.